@@ -70,23 +70,23 @@ dsn_changed_cb (GnomeDbDsnEditor *config, gpointer user_data)
 GdaConnection *
 do_connect_dialog_for_dsn (const gchar *dsn)
 {
-	GtkWidget *dialog, *login;
+	GtkWidget *dialog;
 	gchar *title;
 	GdaConnection *cnc = NULL;
 
 	title = g_strdup_printf (_("Login for %s"), dsn);
 	dialog = gnome_db_login_dialog_new (title);
-	login = gnome_db_login_dialog_get_login_widget (GNOME_DB_LOGIN_DIALOG (dialog));
-	gnome_db_login_set_dsn (GNOME_DB_LOGIN (login), dsn);
+	GnomeDbLogin* login = gnome_db_login_dialog_get_login_widget (GNOME_DB_LOGIN_DIALOG (dialog));
+	gnome_db_login_set_dsn (login, dsn);
 
 	if (gnome_db_login_dialog_run (GNOME_DB_LOGIN_DIALOG (dialog))) {
 		if (!db_client) 
 			db_client = gda_client_new ();
 
 		cnc = gda_client_open_connection (db_client,
-						  gnome_db_login_get_dsn (GNOME_DB_LOGIN (login)),
-						  gnome_db_login_get_username (GNOME_DB_LOGIN (login)),
-						  gnome_db_login_get_password (GNOME_DB_LOGIN (login)),
+						  gnome_db_login_get_dsn (login),
+						  gnome_db_login_get_username (login),
+						  gnome_db_login_get_password (login),
 						  0, NULL);
 	}
 
@@ -170,16 +170,16 @@ dsn_properties_dialog (GtkWindow *parent, const gchar *dsn)
 			break;
 		case TEST_BUTTON:
 		{
-			GtkWidget *dialog, *login;
+			GtkWidget *dialog;
 			gchar *title;
 			GdaConnection *cnc = NULL;
 
 			title = g_strdup_printf (_("Login for %s"), dsn);
 			dialog = gnome_db_login_dialog_new (title);
 			g_free (title);
-			login = gnome_db_login_dialog_get_login_widget (GNOME_DB_LOGIN_DIALOG (dialog));
-			gnome_db_login_set_dsn (GNOME_DB_LOGIN (login), dsn);
-			gnome_db_login_set_show_dsn_selector (GNOME_DB_LOGIN (login), FALSE);
+			GnomeDbLogin* login = gnome_db_login_dialog_get_login_widget (GNOME_DB_LOGIN_DIALOG (dialog));
+			gnome_db_login_set_dsn (login, dsn);
+			gnome_db_login_set_show_dsn_selector (login, FALSE);
 
 			if (gnome_db_login_dialog_run (GNOME_DB_LOGIN_DIALOG (dialog))) {
 				GtkWidget *msgdialog;
@@ -189,9 +189,9 @@ dsn_properties_dialog (GtkWindow *parent, const gchar *dsn)
 					db_client = gda_client_new ();
 				
 				cnc = gda_client_open_connection (db_client,
-								  gnome_db_login_get_dsn (GNOME_DB_LOGIN (login)),
-								  gnome_db_login_get_username (GNOME_DB_LOGIN (login)),
-								  gnome_db_login_get_password (GNOME_DB_LOGIN (login)),
+								  gnome_db_login_get_dsn (login),
+								  gnome_db_login_get_username (login),
+								  gnome_db_login_get_password (login),
 								  0, &error);
 				if (cnc && GDA_IS_CONNECTION (cnc)) {
 					str = g_strdup_printf ("<b>%s</b>", _("Connection successfully opened!"));
