@@ -1,6 +1,6 @@
 /* gnome-db-browser.c
  *
- * Copyright (C) 2006 Vivien Malerba
+ * Copyright (C) 2006 - 2007 Vivien Malerba
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License as
@@ -20,6 +20,7 @@
 
 #include <glib/gi18n-lib.h>
 #include <libgnomedb/libgnomedb.h>
+#include <libgnomedb-extra/libgnomedb-extra.h>
 #include <libgnomedb/gnome-db-util.h>
 #include <gtk/gtk.h>
 
@@ -96,14 +97,24 @@ main (int argc, char **argv)
 
 	/* Browser config */
 	config = g_new0 (BrowserConfig, 1);
-	dictionary = GDA_DICT (gda_dict_new ());
+	dictionary = gda_dict_new ();
 	config->dict = dictionary;
 	config->client = gda_client_new ();
-	g_object_set (G_OBJECT (config->dict), "with_functions", TRUE, NULL);
+	gda_dict_extend_with_functions (config->dict);
 	
 	/* Application init */
-	if (argc > 1) 
+	if (argc > 1) {
+		GdaDataSourceInfo *src;
+
+		src = gda_config_find_data_source (argv[1]);
+		if (!src) {
+			g_print (_("Datasource '%s' is not declared\n"), argv[1]);
+			exit (1);
+		}
+		else 
+			gda_data_source_info_free (src);
 		config->dsn = g_strdup (argv[1]);
+	}
 	else {
 		if (! test_file) {
 			g_print (_("A data source or a dictionary file must be specified.\n"));
@@ -211,7 +222,8 @@ load_file (BrowserConfig *config)
 
 	/* open the connection if possible */
 	if (!cnc && config->dsn && *(config->dsn)) {
-		while (!cnc && get_open_connection_args (config)) {
+		gboolean args_given;
+		while (!cnc && (args_given = get_open_connection_args (config))) {
 			cnc = gda_client_open_connection (config->client, config->dsn, 
 							  config->username, config->password, 
 							  0, &error);
@@ -240,6 +252,9 @@ load_file (BrowserConfig *config)
 				g_object_unref (cnc);
 			}
 		}
+		if (!args_given)
+			/* the user does not want to proceed */
+			exit (0);
 	}
 
 	/* ask permission to perform a DBMS sync if requested */
@@ -379,8 +394,8 @@ update_dbms_data_cb (GtkWidget *wid, BrowserConfig *config)
 	gtk_widget_show (updview);
 	gtk_box_pack_start (GTK_BOX (GTK_DIALOG(dlg)->vbox), updview, TRUE, TRUE, 0);
 	gtk_widget_show (dlg);
-	/* data types, functions and aggregates */
-	if (!gda_dict_update_dbms_data (config->dict, &error)) {
+
+	if (!gda_dict_update_dbms_meta_data (config->dict, 0, NULL, &error)) {
 		if (error->code != GDA_DICT_META_DATA_UPDATE_USER_STOPPED) {
 			GtkWidget *msg;
 			
@@ -396,23 +411,6 @@ update_dbms_data_cb (GtkWidget *wid, BrowserConfig *config)
 		g_error_free (error);
 		error = NULL;	
 	}
-	/* database */
-	if (!stopped && !gda_dict_database_update_dbms_data (db, &error)) {
-		if (error->code != GDA_DICT_DATABASE_META_DATA_UPDATE_USER_STOPPED) {
-			GtkWidget *msg;
-			
-			msg = gtk_message_dialog_new (GTK_WINDOW (config->mainwin), 
-						      GTK_DIALOG_DESTROY_WITH_PARENT,
-						      GTK_MESSAGE_ERROR, GTK_BUTTONS_CLOSE, 
-						      _("Error updating Database metadata:\n%s\n"), error->message);
-			gtk_dialog_run (GTK_DIALOG (msg));
-			gtk_widget_destroy (msg);
-		}
-		else
-			stopped = TRUE;	
-		g_error_free (error);
-		error = NULL;	
-	}
 
 	gtk_widget_destroy (dlg);
 	if (!stopped) {
@@ -435,7 +433,7 @@ update_dbms_data_cb (GtkWidget *wid, BrowserConfig *config)
 static void
 stop_dbms_update_cb (GtkWidget *dlg, gint response, BrowserConfig *config)
 {
-	gda_dict_stop_update_dbms_data (config->dict);
+	gda_dict_stop_update_dbms_meta_data (config->dict);
 }
 
 static void
@@ -444,7 +442,7 @@ sql_console_cb (GtkWidget *wid, BrowserConfig *config)
 	GtkWidget *dlg, *sw, *console;
 
         /* dialog */
-        dlg = gtk_dialog_new_with_buttons (_("SQL console"), NULL, 0,
+        dlg = gtk_dialog_new_with_buttons (_("SQL Console"), NULL, 0,
                                            GTK_STOCK_CLOSE, GTK_RESPONSE_CLOSE, NULL);
         gtk_dialog_set_has_separator (GTK_DIALOG (dlg), FALSE);
         gtk_window_set_title (GTK_WINDOW (dlg), _("SQL Console"));
@@ -550,6 +548,7 @@ build_data_types_page (BrowserConfig *config)
 	gtk_box_pack_start (GTK_BOX (vb), sw, TRUE, TRUE, 0);
 	gtk_scrolled_window_set_policy (GTK_SCROLLED_WINDOW (sw), GTK_POLICY_AUTOMATIC,
 					GTK_POLICY_AUTOMATIC);
+        gtk_scrolled_window_set_shadow_type (GTK_SCROLLED_WINDOW (sw), GTK_SHADOW_IN);
 	textview = gtk_text_view_new ();
 	gtk_container_add (GTK_CONTAINER (sw), textview);
 	gtk_text_view_set_left_margin (GTK_TEXT_VIEW (textview), 5);
@@ -587,7 +586,7 @@ function_get_args (GdaDictFunction *func)
 	gboolean firstarg = TRUE;
 
 	string = g_string_new ("");
-	args = gda_dict_function_get_arg_types (func);
+	args = gda_dict_function_get_arg_dict_types (func);
 	g_string_append (string, " (");
 	while (args) {
 		if (firstarg)
@@ -639,13 +638,13 @@ dt_selection_changed_cb (GnomeDbSelector *mgsel, GObject *dt, BrowserConfig *con
 			switch (config->dt_mode) {
 			case 0:
 				if (GDA_IS_DICT_FUNCTION (list->data)) {
-					ldt = gda_dict_function_get_ret_type (GDA_DICT_FUNCTION (list->data));
+					ldt = gda_dict_function_get_ret_dict_type (GDA_DICT_FUNCTION (list->data));
 					getfunc = (G_OBJECT (ldt) == dt) ? TRUE : FALSE;
 				}
 				break;
 			case 1:
 				if (GDA_IS_DICT_FUNCTION (list->data)) {
-					args = (GSList *) gda_dict_function_get_arg_types (GDA_DICT_FUNCTION (list->data));
+					args = (GSList *) gda_dict_function_get_arg_dict_types (GDA_DICT_FUNCTION (list->data));
 					while (args && !getfunc) {
 						if (args->data == (gpointer) dt)
 							getfunc = TRUE;
@@ -655,7 +654,7 @@ dt_selection_changed_cb (GnomeDbSelector *mgsel, GObject *dt, BrowserConfig *con
 				break;
 			case 2:
 				if (GDA_IS_DICT_AGGREGATE (list->data)) {
-					ldt = gda_dict_aggregate_get_arg_type (GDA_DICT_AGGREGATE (list->data));
+					ldt = gda_dict_aggregate_get_arg_dict_type (GDA_DICT_AGGREGATE (list->data));
 					getfunc = !ldt || (G_OBJECT (ldt) == dt) ? TRUE : FALSE;
 				}
 				break;
@@ -673,7 +672,7 @@ dt_selection_changed_cb (GnomeDbSelector *mgsel, GObject *dt, BrowserConfig *con
 				if (GDA_IS_DICT_FUNCTION (list->data))
 					str = function_get_args (GDA_DICT_FUNCTION (list->data));
 				else {
-					if ((ldt = gda_dict_aggregate_get_arg_type (GDA_DICT_AGGREGATE (list->data)))) {
+					if ((ldt = gda_dict_aggregate_get_arg_dict_type (GDA_DICT_AGGREGATE (list->data)))) {
 						str = g_strdup_printf (" (%s)", gda_object_get_name (GDA_OBJECT (ldt)));
 					}
 					else
@@ -783,6 +782,7 @@ build_tables_views_page (BrowserConfig *config)
 	gtk_box_pack_start (GTK_BOX (vb), sw, TRUE, TRUE, 0);
 	gtk_scrolled_window_set_policy (GTK_SCROLLED_WINDOW (sw), GTK_POLICY_AUTOMATIC,
 					GTK_POLICY_AUTOMATIC);
+        gtk_scrolled_window_set_shadow_type (GTK_SCROLLED_WINDOW (sw), GTK_SHADOW_IN);
 	textview = gtk_text_view_new ();
 	gtk_container_add (GTK_CONTAINER (sw), textview);
 	gtk_text_view_set_left_margin (GTK_TEXT_VIEW (textview), 5);
@@ -971,7 +971,7 @@ tables_selection_changed_cb (GnomeDbSelector *mgsel, GObject *obj, BrowserConfig
 			gtk_text_buffer_insert (config->db_textbuffer, &current, gda_object_get_name (GDA_OBJECT (obj)), -1);
 			gtk_text_buffer_insert (config->db_textbuffer, &current, "\n\n", -1);
 
-			type = gda_entity_field_get_data_type (GDA_ENTITY_FIELD (field));
+			type = gda_entity_field_get_dict_type (GDA_ENTITY_FIELD (field));
 			gtk_text_buffer_insert (config->db_textbuffer, &current, _("Data type:"), -1);
 			gtk_text_buffer_insert (config->db_textbuffer, &current, " ", -1);
 			gtk_text_buffer_insert (config->db_textbuffer, &current, gda_object_get_name (GDA_OBJECT (type)), -1);
@@ -1045,7 +1045,6 @@ table_view_contents (GtkWidget *button, BrowserConfig *config)
 	GdaQueryField *field;
 	GObject *sel;
 	GtkWidget *grid, *dlg;
-	gchar *str;
 
 	sel = gnome_db_selector_get_selected_object (GNOME_DB_SELECTOR (config->db_selector));
 	if (!sel || !GDA_IS_DICT_TABLE (sel))
@@ -1056,30 +1055,64 @@ table_view_contents (GtkWidget *button, BrowserConfig *config)
 
 	if (!dlg) {
 		GdaDataModel *query_model;
+		gchar *str;
 
 		/* Query preparation: "SELECT * FROM table" */
-		query = GDA_QUERY (gda_query_new (config->dict));
+		query = gda_query_new (config->dict);
 		gda_query_set_query_type (query, GDA_QUERY_TYPE_SELECT);
 		
-		target = GDA_QUERY_TARGET (gda_query_target_new (query, gda_object_get_name (GDA_OBJECT (table))));
+		target = gda_query_target_new (query, gda_object_get_name (GDA_OBJECT (table)));
 		gda_query_add_target (query, target, NULL);
 		g_object_unref (G_OBJECT (target));
 		
-		field = GDA_QUERY_FIELD (gda_query_field_all_new (query, gda_object_get_name (GDA_OBJECT (table))));;
+		field = gda_query_field_all_new (query, gda_object_get_name (GDA_OBJECT (table)));
 		gda_entity_add_field (GDA_ENTITY (query), GDA_ENTITY_FIELD (field));
 		g_object_unref (G_OBJECT (field));
 		
 		
 		/* Grid */
 		query_model = gda_data_model_query_new (query);
+		gda_data_model_query_compute_modification_queries (GDA_DATA_MODEL_QUERY (query_model),
+								   NULL, 
+								   GDA_DATA_MODEL_QUERY_OPTION_USE_ALL_FIELDS_IF_NO_PK, 
+								   NULL);
+		g_object_unref (query);
+		
+		/* print modification queries */
+		g_object_get (G_OBJECT (query_model), "insert_query", &query, NULL);
+		if (query) {
+			str = gda_renderer_render_as_sql (GDA_RENDERER (query), NULL, NULL,
+							  GDA_RENDERER_PARAMS_AS_DETAILED, NULL);
+			g_print("===> SQL insert is %s \n", str);
+			g_free (str);
+			g_object_unref (query);
+		}
+		g_object_get (G_OBJECT (query_model), "update_query", &query, NULL);
+		if (query) {
+			str = gda_renderer_render_as_sql (GDA_RENDERER (query), NULL, NULL,
+							  GDA_RENDERER_PARAMS_AS_DETAILED, NULL);
+			g_print("===> SQL update is %s \n", str);
+			g_free (str);
+			g_object_unref (query);
+		}
+		g_object_get (G_OBJECT (query_model), "delete_query", &query, NULL);
+		if (query) {
+			str = gda_renderer_render_as_sql (GDA_RENDERER (query), NULL, NULL,
+							  GDA_RENDERER_PARAMS_AS_DETAILED, NULL);
+			g_print("===> SQL delete is %s \n", str);
+			g_free (str);
+			g_object_unref (query);
+		}
+
+		/* grid widget */
+		grid = gnome_db_grid_new (query_model);
+		g_object_unref (query_model);
+
 		if (gda_dict_table_is_view (table)) 
 			str = g_strdup_printf (_("Contents of view '%s'"), gda_object_get_name (GDA_OBJECT (table)));
 		else 
 			str = g_strdup_printf (_("Contents of table '%s'"), gda_object_get_name (GDA_OBJECT (table)));
-		grid = gnome_db_grid_new (query_model);
-		g_object_unref (query_model);
-
-		g_object_set (G_OBJECT (grid), "title_string", str, NULL);
+		/*g_object_set (G_OBJECT (grid), "title_string", str, NULL);*/
 		dlg = gtk_dialog_new_with_buttons (str, GTK_WINDOW (config->mainwin), 0,
 						   GTK_STOCK_CLOSE,
 						   GTK_RESPONSE_ACCEPT, NULL);
@@ -1090,7 +1123,6 @@ table_view_contents (GtkWidget *button, BrowserConfig *config)
 		gtk_widget_show_all (dlg);
 		gnome_db_grid_set_sample_size (GNOME_DB_GRID (grid), 300);
 
-		g_object_unref (G_OBJECT (query));
 		g_object_set_data (G_OBJECT (table), "contents", dlg);
 		g_signal_connect (G_OBJECT (dlg), "response",
 				  G_CALLBACK (dialog_exec_response_cb), table);
@@ -1105,3 +1137,6 @@ dialog_exec_response_cb (GtkDialog *dlg, gint response, GObject *obj)
 	gtk_widget_destroy (GTK_WIDGET (dlg));
 	g_object_set_data (G_OBJECT (obj), "contents", NULL);
 }
+
+
+
