@@ -163,7 +163,7 @@ gnome_db_canvas_item_class_init (GnomeDbCanvasItemClass * class)
 		 g_param_spec_string ("tip_text", NULL, NULL, NULL, (G_PARAM_READABLE | G_PARAM_WRITABLE)));
 	g_object_class_install_property (
 		object_class, PROP_GRAPH_ITEM,
-		g_param_spec_pointer ("graph_item", NULL, NULL, (G_PARAM_READABLE | G_PARAM_WRITABLE)));
+		g_param_spec_object ("graph_item", NULL, NULL, GDA_TYPE_GRAPH_ITEM, (G_PARAM_READABLE | G_PARAM_WRITABLE)));
 }
 
 static void
@@ -215,7 +215,10 @@ gnome_db_canvas_item_finalize (GObject   * object)
 	
 	citem = GNOME_DB_CANVAS_ITEM (object);
 	if (citem->priv) {
-		if (citem->priv->graph_item) 
+		if (citem->priv->graph_item)
+			g_object_unref (citem->priv->graph_item);
+
+		if (citem->priv->graph_item)
 			graph_item_destroyed_cb (citem->priv->graph_item, citem);
 
 		if (citem->priv->tooltip_text) 
@@ -235,9 +238,9 @@ gnome_db_canvas_item_set_property    (GObject *object,
 				const GValue *value,
 				GParamSpec *pspec)
 {
-	GnomeDbCanvasItem *citem;
-	const gchar *str;
-	gpointer ptr;
+	GnomeDbCanvasItem *citem = NULL;
+	const gchar *str = NULL;
+	GObject* propobject = NULL;
 
 	citem = GNOME_DB_CANVAS_ITEM (object);
 
@@ -262,21 +265,29 @@ gnome_db_canvas_item_set_property    (GObject *object,
 			citem->priv->tooltip_text = g_strdup (str);
 		break;
 	case PROP_GRAPH_ITEM:
-		ptr = g_value_get_pointer (value);
-		if (ptr == citem->priv->graph_item)
+		propobject = g_value_get_object (value);
+		if (propobject == G_OBJECT (citem->priv->graph_item))
 			return;
 
-		if (citem->priv->graph_item) 
-			graph_item_destroyed_cb (citem->priv->graph_item, citem);
+		if (citem->priv->graph_item) {
+			g_object_unref (citem->priv->graph_item);
+		}
 
-		if (ptr) {
-			g_return_if_fail (GDA_IS_GRAPH_ITEM (ptr));
-			gda_object_connect_destroy (ptr, G_CALLBACK (graph_item_destroyed_cb), citem);
-			g_signal_connect (G_OBJECT (ptr), "moved",
+		if (citem->priv->graph_item) {
+			graph_item_destroyed_cb (citem->priv->graph_item, citem);
+			citem->priv->graph_item = NULL;
+		}
+
+		if (propobject) {
+			g_return_if_fail (GDA_IS_GRAPH_ITEM (propobject));
+			gda_object_connect_destroy (propobject, G_CALLBACK (graph_item_destroyed_cb), citem);
+			g_signal_connect (G_OBJECT (propobject), "moved",
 					  G_CALLBACK (graph_item_moved_cb), citem);
 
 			/* set the position according to the GdaGraphItem */
-			citem->priv->graph_item = ptr;
+			citem->priv->graph_item = GDA_GRAPH_ITEM(propobject);
+			g_object_ref (propobject);
+
 			graph_item_moved_cb (citem->priv->graph_item, citem);
 		}
 	}
