@@ -32,14 +32,14 @@ G_BEGIN_DECLS
 #define GNOME_DB_TYPE_DATA_CELL_RENDERER_INFO			(gnome_db_data_cell_renderer_info_get_type ())
 #define GNOME_DB_DATA_CELL_RENDERER_INFO(obj)			(G_TYPE_CHECK_INSTANCE_CAST ((obj), GNOME_DB_TYPE_DATA_CELL_RENDERER_INFO, GnomeDbDataCellRendererInfo))
 #define GNOME_DB_DATA_CELL_RENDERER_INFO_CLASS(klass)		(G_TYPE_CHECK_CLASS_CAST ((klass), GNOME_DB_TYPE_DATA_CELL_RENDERER_INFO, GnomeDbDataCellRendererInfoClass))
-#define IS_GNOME_DB_DATA_CELL_RENDERER_INFO(obj)		(G_TYPE_CHECK_INSTANCE_TYPE ((obj), GNOME_DB_TYPE_DATA_CELL_RENDERER_INFO))
-#define IS_GNOME_DB_DATA_CELL_RENDERER_INFO_CLASS(klass)	(G_TYPE_CHECK_CLASS_TYPE ((klass), GNOME_DB_TYPE_DATA_CELL_RENDERER_INFO))
+#define GNOME_DB_IS_DATA_CELL_RENDERER_INFO(obj)		(G_TYPE_CHECK_INSTANCE_TYPE ((obj), GNOME_DB_TYPE_DATA_CELL_RENDERER_INFO))
+#define GNOME_DB_IS_DATA_CELL_RENDERER_INFO_CLASS(klass)	(G_TYPE_CHECK_CLASS_TYPE ((klass), GNOME_DB_TYPE_DATA_CELL_RENDERER_INFO))
 #define GNOME_DB_DATA_CELL_RENDERER_INFO_GET_CLASS(obj)         (G_TYPE_INSTANCE_GET_CLASS ((obj), GNOME_DB_TYPE_DATA_CELL_RENDERER_INFO, GnomeDbDataCellRendererInfoClass))
 
 typedef struct _GnomeDbDataCellRendererInfo GnomeDbDataCellRendererInfo;
 typedef struct _GnomeDbDataCellRendererInfoClass GnomeDbDataCellRendererInfoClass;
 typedef struct _GnomeDbDataCellRendererInfoPriv GnomeDbDataCellRendererInfoPriv;
-typedef enum   _GnomeDbDataCellRendererInfoStatus GnomeDbDataCellRendererInfoStatus;
+/* typedef enum   _GnomeDbDataCellRendererInfoStatus GnomeDbDataCellRendererInfoStatus; */
 
 struct _GnomeDbDataCellRendererInfo
 {
@@ -54,7 +54,7 @@ struct _GnomeDbDataCellRendererInfoClass
 	
 	void (* status_changed) (GnomeDbDataCellRendererInfo *cell_renderer_info,
 				 const gchar                 *path,
-				 GValueAttribute            requested_action);
+				 GdaValueAttribute            requested_action);
 };
 
 GType            gnome_db_data_cell_renderer_info_get_type  (void);
