@@ -58,7 +58,8 @@ struct _GnomeDbDataCellRendererTextualClass
 };
 
 GType            gnome_db_data_cell_renderer_textual_get_type (void);
-GtkCellRenderer *gnome_db_data_cell_renderer_textual_new      (GdaDataHandler *dh, GType type);
+GtkCellRenderer *gnome_db_data_cell_renderer_textual_new      (GdaDataHandler *dh, GType type, 
+							       const gchar *options);
 
 
 #ifdef __cplusplus
