@@ -50,8 +50,8 @@ static GValue         *gnome_db_entry_wrapper_get_value         (GnomeDbDataEntr
 static void            gnome_db_entry_wrapper_set_value_orig    (GnomeDbDataEntry *de, const GValue *value);
 static const GValue   *gnome_db_entry_wrapper_get_value_orig    (GnomeDbDataEntry *de);
 static void            gnome_db_entry_wrapper_set_value_default (GnomeDbDataEntry *de, const GValue *value);
-static void            gnome_db_entry_wrapper_set_attributes    (GnomeDbDataEntry *de, guint attrs, guint mask);
-static guint           gnome_db_entry_wrapper_get_attributes    (GnomeDbDataEntry *de);
+static void            gnome_db_entry_wrapper_set_attributes    (GnomeDbDataEntry *de, GdaValueAttribute attrs, guint mask);
+static GdaValueAttribute gnome_db_entry_wrapper_get_attributes    (GnomeDbDataEntry *de);
 static GdaDataHandler *gnome_db_entry_wrapper_get_handler       (GnomeDbDataEntry *de);
 static gboolean        gnome_db_entry_wrapper_expand_in_layout  (GnomeDbDataEntry *de);
 static void            gnome_db_entry_wrapper_set_editable      (GnomeDbDataEntry *de, gboolean editable);
@@ -714,10 +714,10 @@ gnome_db_entry_wrapper_set_attributes (GnomeDbDataEntry *iface, guint attrs, gui
 	g_signal_emit_by_name (G_OBJECT (mgwrap), "status_changed");
 }
 
-static guint
+static GdaValueAttribute
 gnome_db_entry_wrapper_get_attributes (GnomeDbDataEntry *iface)
 {
-	guint retval = 0;
+	GdaValueAttribute retval = 0;
 	GnomeDbEntryWrapper *mgwrap;
 	GValue *value = NULL;
 	gboolean has_current_value;
