@@ -53,7 +53,7 @@ typedef enum {
  * - @decimal_sep is the decimal separator, or 0 for the default separator
  */
 struct _GnomeDbFormatEntryPrivate {
-	gchar   *held_text_if_null; 
+	gboolean is_null; /* TRUE => entry represents NULL */
 
 	guchar   internal_changes;
 	guchar   disable_completions;
@@ -236,7 +236,7 @@ static void
 gnome_db_format_entry_init (GnomeDbFormatEntry *entry)
 {
 	entry->priv = g_new0 (GnomeDbFormatEntryPrivate, 1);
-	entry->priv->held_text_if_null = NULL;
+	entry->priv->is_null = TRUE;
 	entry->priv->internal_changes = 0;
 	entry->priv->disable_completions = 0;
 	entry->priv->max_length = 0; /* no specific limitation */
@@ -282,7 +282,6 @@ gnome_db_format_entry_finalize (GObject *object)
 
         entry = GNOME_DB_FORMAT_ENTRY (object);
         if (entry->priv) {
-		g_free (entry->priv->held_text_if_null);
                 g_free (entry->priv->prefix);
                 g_free (entry->priv->suffix);
                 g_free (entry->priv->i_format);
@@ -733,7 +732,7 @@ gnome_db_format_entry_get_text (GnomeDbFormatEntry *entry)
 	g_return_val_if_fail (GNOME_DB_IS_FORMAT_ENTRY (entry), NULL);
 	g_return_val_if_fail (entry->priv, NULL);
 
-	if (entry->priv->held_text_if_null)
+	if (entry->priv->is_null)
 		text = NULL;
 	else {
 		text = get_raw_text (entry);
@@ -782,9 +781,12 @@ get_raw_text (GnomeDbFormatEntry *entry)
 	memcpy (ret, text + index, length);
 	ret [length] = 0;
 
-	for (ptr = ret; *ptr; ptr = g_utf8_next_char (ptr), index++) {
-		if ((*ptr == '_') && char_is_writable (entry, index))
-			*ptr = ' ';
+	if (entry->priv->user_format) {
+		/* replace the '_' with ' ' */
+		for (ptr = ret; *ptr; ptr = g_utf8_next_char (ptr), index++) {
+			if ((*ptr == '_') && char_is_writable (entry, index))
+				*ptr = ' ';
+		}
 	}
 
 	return ret;
@@ -801,7 +803,7 @@ get_raw_text (GnomeDbFormatEntry *entry)
  * be completely empty, whereas if @text is the empty string (""), then
  * @entry will display the prefix and/or suffix and/or format string if they have
  * been set. Except this case, calling this method is similar to calling
- * gtk_entry_get_text()
+ * gtk_entry_set_text()
  */
 void
 gnome_db_format_entry_set_text (GnomeDbFormatEntry *entry, const gchar *text)
@@ -812,9 +814,7 @@ gnome_db_format_entry_set_text (GnomeDbFormatEntry *entry, const gchar *text)
 	gtk_entry_set_text (GTK_ENTRY (entry), text ? text : "");
 
 	if (!text) {
-		const gchar *text;
-		text = gtk_entry_get_text (GTK_ENTRY (entry));
-		entry->priv->held_text_if_null = g_strdup (text);
+		entry->priv->is_null = TRUE;
 		signal_handlers_block (entry);
 		gtk_editable_delete_text (GTK_EDITABLE (entry), 0, -1);
 		signal_handlers_unblock (entry);
@@ -1027,7 +1027,7 @@ adjust_numeric_display (GnomeDbFormatEntry *entry)
 	if (!attr.is_numerical)
 		return FALSE;
 
-	if (entry->priv->held_text_if_null)
+	if (entry->priv->is_null)
 		return FALSE;
 
 	ENTER_INTERNAL_CHANGES (entry);
@@ -1450,12 +1450,14 @@ test_text_validity (GnomeDbFormatEntry *entry, const gchar *text)
  * Returns: TRUE if the internal format has been adjusted to take into account @inschar
  */
 static gboolean
-adjust_computed_format_at_insert (GnomeDbFormatEntry *entry, const gunichar inschar, gint *position)
+adjust_computed_format_at_insert (GnomeDbFormatEntry *entry, const gunichar inschar, gint *position, 
+				  gboolean *out_ignore_this_char)
 {
 	gint insert_pos;
 	NumAttr attr;
 	gboolean retval = FALSE;
 
+	*out_ignore_this_char = FALSE;
 	insert_pos = *position;
 	if (entry->priv->prefix)
 		insert_pos -= g_utf8_strlen (entry->priv->prefix, -1);
@@ -1514,6 +1516,16 @@ adjust_computed_format_at_insert (GnomeDbFormatEntry *entry, const gunichar insc
 			test_text [test_length + bsize] = 0;
 		}
 		else {
+			/* test if char to insert is the decimal separator */
+			if (inschar == entry->priv->decimal_sep) {
+				if (g_utf8_get_char (g_utf8_offset_to_pointer (test_text, insert_pos)) == 
+				    entry->priv->decimal_sep) {
+					retval = TRUE;
+					*out_ignore_this_char = TRUE;
+					goto num_out;
+				}
+			}
+			
 			gchar buffer [6];
 			gint bsize;
 
@@ -1592,14 +1604,15 @@ insert_text_cb (GtkEditable *editable, const gchar *text, gint text_length, gint
 		goto exit;
 	}
 
-	if (entry->priv->held_text_if_null) {
+	if (entry->priv->is_null) {
 		gint pos = 0;
+		/* restore a correct display before treating @text */
 		signal_handlers_block (entry);
-		gtk_editable_insert_text (editable, entry->priv->held_text_if_null, 
-					  strlen (entry->priv->held_text_if_null), &pos);
+		gtk_editable_insert_text (editable, entry->priv->i_format, 
+					  g_utf8_strlen (entry->priv->i_format, -1), &pos);
 		signal_handlers_unblock (entry);
-		g_free (entry->priv->held_text_if_null);
-		entry->priv->held_text_if_null = NULL;
+		entry->priv->is_null = FALSE;
+		gtk_editable_delete_text (editable, 0, gtk_entry_get_max_length (GTK_ENTRY (entry)));
 	}
 
 	text_length = g_utf8_strlen (text, -1);
@@ -1635,10 +1648,16 @@ insert_text_cb (GtkEditable *editable, const gchar *text, gint text_length, gint
 	for (ti = 0, tptr = text; ti < text_length; ) {
 		gunichar tchar, fchar;
 		gboolean consume_char = TRUE;
+		gboolean noinsert_char = FALSE;
 		tchar = g_utf8_get_char (tptr);
 		if (!entry->priv->user_format) {
-			if (!adjust_computed_format_at_insert (entry, tchar, position))
+			if (!adjust_computed_format_at_insert (entry, tchar, position, &noinsert_char))
 				break;
+			if (noinsert_char) {
+				*position += 1;
+				gtk_editable_set_position (editable, *position);
+				goto chars_next;
+			}
 
 			if (write_pos < 0) {
 				write_pos = get_first_writable_index (entry, GNOME_DB_FORMAT_ENTRY_RIGHT);
@@ -1706,6 +1725,7 @@ insert_text_cb (GtkEditable *editable, const gchar *text, gint text_length, gint
 			gtk_editable_set_position (editable, *position);
 		}
 
+	chars_next:
 		fi = *position;
 		if (consume_char) {
 			ti++;
