@@ -43,6 +43,7 @@ struct _GnomeDbDataEntryIface
 	void            (* contents_modified)    (GnomeDbDataEntry *de);
 	void            (* contents_activated)   (GnomeDbDataEntry *de);
 	void            (* status_changed)       (GnomeDbDataEntry *de);
+	gboolean        (* contents_valid)       (GnomeDbDataEntry *de, GError **error);
 
 	/* virtual table */
 	void            (*set_value_type)        (GnomeDbDataEntry *de, GType type);
@@ -53,7 +54,7 @@ struct _GnomeDbDataEntryIface
 	const GValue   *(*get_value_orig)        (GnomeDbDataEntry *de);
 	void            (*set_value_default)     (GnomeDbDataEntry *de, const GValue * value);
 	void            (*set_attributes)        (GnomeDbDataEntry *de, GdaValueAttribute attrs, GdaValueAttribute mask);
-	GdaValueAttribute (*get_attributes)        (GnomeDbDataEntry *de);
+	GdaValueAttribute (*get_attributes)      (GnomeDbDataEntry *de);
 	GdaDataHandler *(*get_handler)           (GnomeDbDataEntry *de);
 	gboolean        (*expand_in_layout)      (GnomeDbDataEntry *de);
 	void            (*set_editable)          (GnomeDbDataEntry *de, gboolean editable);
@@ -70,13 +71,14 @@ GType           gnome_db_data_entry_get_value_type         (GnomeDbDataEntry *de
 
 void            gnome_db_data_entry_set_value              (GnomeDbDataEntry *de, const GValue * value);
 GValue         *gnome_db_data_entry_get_value              (GnomeDbDataEntry *de);
+gboolean        gnome_db_data_entry_is_contents_valid      (GnomeDbDataEntry *de, GError **error);
 void            gnome_db_data_entry_set_value_orig         (GnomeDbDataEntry *de, const GValue * value);
 const GValue   *gnome_db_data_entry_get_value_orig         (GnomeDbDataEntry *de);
 void            gnome_db_data_entry_set_current_as_orig    (GnomeDbDataEntry *de);
 void            gnome_db_data_entry_set_value_default      (GnomeDbDataEntry *de, const GValue * value);
 
 void            gnome_db_data_entry_set_attributes         (GnomeDbDataEntry *de, GdaValueAttribute attrs, GdaValueAttribute mask);
-GdaValueAttribute gnome_db_data_entry_get_attributes (GnomeDbDataEntry *de);
+GdaValueAttribute gnome_db_data_entry_get_attributes       (GnomeDbDataEntry *de);
 
 GdaDataHandler *gnome_db_data_entry_get_handler            (GnomeDbDataEntry *de);
 gboolean        gnome_db_data_entry_expand_in_layout       (GnomeDbDataEntry *de);
