@@ -31,6 +31,21 @@ static void gnome_db_data_import_class_init (GnomeDbDataImportClass *class);
 static void gnome_db_data_import_init (GnomeDbDataImport *wid);
 static void gnome_db_data_import_dispose (GObject *object);
 
+static void gnome_db_data_import_set_property (GObject *object,
+                                               guint param_id,
+                                               const GValue *value,
+                                               GParamSpec *pspec);
+static void gnome_db_data_import_get_property (GObject *object,
+                                               guint param_id,
+                                               GValue *value,
+                                               GParamSpec *pspec);
+
+enum {
+	PROP_0,
+
+	PROP_DICT
+};
+
 enum {
 	SEP_COMMA,
 	SEP_SEMICOL,
@@ -98,6 +113,13 @@ gnome_db_data_import_class_init (GnomeDbDataImportClass * class)
 	parent_class = g_type_class_peek_parent (class);
 
 	object_class->dispose = gnome_db_data_import_dispose;
+	object_class->set_property = gnome_db_data_import_set_property;
+	object_class->get_property = gnome_db_data_import_get_property;
+
+	g_object_class_install_property (object_class, PROP_DICT,
+	                                 g_param_spec_object ("dict", NULL, NULL,
+	                                                      GDA_TYPE_DICT,
+	                                                      G_PARAM_READWRITE | G_PARAM_CONSTRUCT_ONLY));
 }
 
 static void
@@ -308,13 +330,8 @@ gnome_db_data_import_new (GdaDict *dict)
 		
 	g_return_val_if_fail (!dict || GDA_IS_DICT (dict), NULL);
 
-	import = GNOME_DB_DATA_IMPORT(g_object_new (GNOME_DB_TYPE_DATA_IMPORT, NULL));
+	import = GNOME_DB_DATA_IMPORT(g_object_new (GNOME_DB_TYPE_DATA_IMPORT, "dict", dict, NULL));
 	
-	import->priv->dict = ASSERT_DICT (dict);
-	
-	g_object_weak_ref (G_OBJECT (import->priv->dict),
-			   (GWeakNotify) gda_dict_weak_notify, import);
-
 	return GTK_WIDGET (import);
 }
 
@@ -355,6 +372,43 @@ gnome_db_data_import_dispose (GObject *object)
 	parent_class->dispose (object);
 }
 
+static void gnome_db_data_import_set_property (GObject *object,
+                                               guint param_id,
+                                               const GValue *value,
+                                               GParamSpec *pspec)
+{
+	GnomeDbDataImport *import;
+	GdaDict *dict;
+
+	import = GNOME_DB_DATA_IMPORT(object);
+
+	switch (param_id) {
+	case PROP_DICT:
+		dict = GDA_DICT (g_value_get_object (value));
+		import->priv->dict = ASSERT_DICT (dict);
+	
+		g_object_weak_ref (G_OBJECT (dict),
+				   (GWeakNotify) gda_dict_weak_notify, import);
+
+		break;
+	}
+}
+
+static void gnome_db_data_import_get_property (GObject *object,
+                                               guint param_id,
+                                               GValue *value,
+                                               GParamSpec *pspec)
+{
+	GnomeDbDataImport *import;
+
+	import = GNOME_DB_DATA_IMPORT(object);
+
+	switch (param_id) {
+	case PROP_DICT:
+		g_value_set_object(value, G_OBJECT(import->priv->dict));
+		break;
+	}
+}
 
 /*
  * create the entries in the widget
@@ -451,6 +505,7 @@ spec_changed_cb (GtkWidget *wid, GnomeDbDataImport *import)
 		g_object_set (info, "flags", 
 			      GNOME_DB_DATA_WIDGET_INFO_CHUNCK_CHANGE_BUTTONS | 
 			      GNOME_DB_DATA_WIDGET_INFO_CURRENT_ROW, NULL);
+		g_object_unref (info);
 
 		gtk_box_pack_start (GTK_BOX (import->priv->preview_box), import->priv->preview_grid, TRUE, TRUE, 0);
 		gtk_widget_show (import->priv->preview_grid);
