@@ -254,7 +254,7 @@ gnome_db_data_store_set_property (GObject *object,
 			else
 				proxy = (GdaDataProxy *) gda_data_proxy_new (model);
 			store->priv->proxy = proxy;
-
+			
 			gda_object_connect_destroy (store->priv->proxy,
 						    G_CALLBACK (proxy_destroyed_cb), store);
 			/* connect to row changes */
@@ -289,7 +289,7 @@ gnome_db_data_store_get_property (GObject *object,
 		switch (param_id) {
 		case PROP_MODEL:
 			/* FIXME: the requested model can be different than the proxy as
-			   the aim of this property is to retreive the data model given to
+			   the aim of this property is to retrieve the data model given to
 			   the new() function (which is the same as the one given to the PROP_MODEL
 			   property) */
                 case PROP_PROXY:
@@ -339,7 +339,7 @@ gnome_db_data_store_new (GdaDataModel *model)
  */
 gboolean
 gnome_db_data_store_set_value (GnomeDbDataStore *store, GtkTreeIter *iter,
-			       gint col, const GdaValue *value)
+			       gint col, const GValue *value)
 {
 	gint row, model_nb_cols;
 
@@ -362,7 +362,7 @@ gnome_db_data_store_set_value (GnomeDbDataStore *store, GtkTreeIter *iter,
 			g_warning (_("Trying to modify a read-only row"));
 			break;
 		case DATA_STORE_COL_TO_DELETE:
-			if (gda_value_get_boolean (value))
+			if (g_value_get_boolean (value))
 				gda_data_proxy_delete (store->priv->proxy, row);
 			else
 				gda_data_proxy_undelete (store->priv->proxy, row);
@@ -385,7 +385,7 @@ gnome_db_data_store_set_value (GnomeDbDataStore *store, GtkTreeIter *iter,
 	/* value's attributes */
 	if ((col >= model_nb_cols) && (col < 2 * model_nb_cols)) {
 		gda_data_proxy_alter_value_attributes (store->priv->proxy, row, col - model_nb_cols, 
-						       gda_value_get_uinteger (value));
+						       g_value_get_uint (value));
 		return TRUE;
 	}
 }
@@ -443,7 +443,7 @@ gnome_db_data_store_undelete (GnomeDbDataStore *store, GtkTreeIter *iter)
  *
  * Appends a new row.
  *
- * Returns: TRUE if no error occured
+ * Returns: TRUE if no error occurred
  */
 gboolean
 gnome_db_data_store_append (GnomeDbDataStore *store, GtkTreeIter *iter)
@@ -487,7 +487,7 @@ gnome_db_data_store_get_proxy (GnomeDbDataStore *store)
  * @iter: a valid #GtkTreeIter
  *
  * Get the number of the row represented by @iter
- * Returns: the row number, or -1 if an error occured
+ * Returns: the row number, or -1 if an error occurred
  */
 gint
 gnome_db_data_store_get_row_from_iter (GnomeDbDataStore *store, GtkTreeIter *iter)
@@ -504,7 +504,7 @@ gnome_db_data_store_get_row_from_iter (GnomeDbDataStore *store, GtkTreeIter *ite
  * gnome_db_data_store_get_iter_from_values
  * @store: a #GnomeDbDataStore object
  * @iter: an unset #GtkTreeIter to set to the requested row
- * @values: a list of #GdaValue values
+ * @values: a list of #GValue values
  * @cols_index: an array of #gint containing the column number to match each value of @values
  *
  * Sets @iter to the first row where all the values in @values at the columns identified at
@@ -542,7 +542,7 @@ gnome_db_data_store_get_iter_from_values (GnomeDbDataStore *store, GtkTreeIter *
 /* 
  * GtkTreeModel Interface implementation
  *
- * REM about the GtkTreeIter: only the iter->user_data is used to retreive a row in the data model:
+ * REM about the GtkTreeIter: only the iter->user_data is used to retrieve a row in the data model:
  *     iter->user_data contains the requested row number in the GtkTreeModel numbers
  *     iter->stamp is reset any time the model changes.
  */
@@ -661,7 +661,7 @@ static void
 data_store_get_value (GtkTreeModel *tree_model, GtkTreeIter *iter, gint column, GValue *value)
 {
 	GnomeDbDataStore *store;
-	const GdaValue *tmp;
+	const GValue *tmp;
 	GType rettype;
 	gint model_nb_cols;
 
