@@ -331,8 +331,8 @@ gnome_db_dsn_assistant_class_init (GnomeDbDsnAssistantClass *klass)
 			      G_SIGNAL_RUN_LAST,
 			      G_STRUCT_OFFSET (GnomeDbDsnAssistantClass, finished),
 			      NULL, NULL,
-			      g_cclosure_marshal_VOID__INT,
-			      G_TYPE_NONE, 1, G_TYPE_INT);
+			      g_cclosure_marshal_VOID__BOOLEAN,
+			      G_TYPE_NONE, 1, G_TYPE_BOOLEAN);
 
 	klass->finished = NULL;
 	object_class->finalize = gnome_db_dsn_assistant_finalize;
@@ -429,7 +429,7 @@ gnome_db_dsn_assistant_init (GnomeDbDsnAssistant *assistant,
 	gtk_label_set_line_wrap (GTK_LABEL (label), TRUE);
 	gtk_table_attach (GTK_TABLE (table), label, 0, 2, 0, 1, GTK_EXPAND | GTK_FILL, 0, 0, 0);
 
-	str = utility_markup_title (_("Data source name"), FALSE);
+	str = gnome_db_utility_markup_title (_("Data source name"), FALSE);
 	label = gtk_label_new ("");
 	gtk_label_set_markup (GTK_LABEL (label), str);
 	g_free (str);
@@ -452,7 +452,7 @@ gnome_db_dsn_assistant_init (GnomeDbDsnAssistant *assistant,
 	else
 		assistant->priv->general_is_global = NULL;
 
-	str = utility_markup_title (_("Database type"), FALSE);
+	str = gnome_db_utility_markup_title (_("Database type"), FALSE);
 	label = gtk_label_new ("");
 	gtk_label_set_markup (GTK_LABEL (label), str);
 	g_free (str);
