@@ -29,7 +29,7 @@ G_BEGIN_DECLS
 #define GNOME_DB_TYPE_FORM          (gnome_db_form_get_type())
 #define GNOME_DB_FORM(obj)          G_TYPE_CHECK_INSTANCE_CAST (obj, gnome_db_form_get_type(), GnomeDbForm)
 #define GNOME_DB_FORM_CLASS(klass)  G_TYPE_CHECK_CLASS_CAST (klass, gnome_db_form_get_type (), GnomeDbFormClass)
-#define IS_GNOME_DB_FORM(obj)       G_TYPE_CHECK_INSTANCE_TYPE (obj, gnome_db_form_get_type ())
+#define GNOME_DB_IS_FORM(obj)       G_TYPE_CHECK_INSTANCE_TYPE (obj, gnome_db_form_get_type ())
 
 
 typedef struct _GnomeDbForm      GnomeDbForm;
