@@ -1,6 +1,6 @@
 /* gnome-db-raw-form.c
  *
- * Copyright (C) 2002 - 2006 Vivien Malerba
+ * Copyright (C) 2002 - 2007 Vivien Malerba
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License as
@@ -20,10 +20,12 @@
 
 #include <string.h>
 #include <libgda/libgda.h>
+#include <libgda/gda-data-proxy.h>
 #include <glib/gi18n-lib.h>
 #include "gnome-db-raw-form.h"
 #include "gnome-db-data-widget.h"
 #include "gnome-db-basic-form.h"
+#include "utility.h"
 
 static void gnome_db_raw_form_class_init (GnomeDbRawFormClass * class);
 static void gnome_db_raw_form_init (GnomeDbRawForm *wid);
@@ -40,8 +42,10 @@ static void gnome_db_raw_form_get_property (GObject *object,
 
 static void gnome_db_raw_form_initialize (GnomeDbRawForm *form, GtkWidget *layout, GHashTable *box_widgets);
 
+static gboolean iter_row_to_change_cb (GdaDataModelIter *iter, gint row, GnomeDbRawForm *form);
 static void iter_row_changed_cb (GdaDataModelIter *iter, gint row, GnomeDbRawForm *form);
 static void proxy_changed_cb (GdaDataProxy *proxy, GnomeDbRawForm *form);
+static void proxy_reset_cb (GdaDataProxy *proxy, GnomeDbRawForm *form);
 static void proxy_row_inserted_or_removed_cb (GdaDataProxy *proxy, gint row, GnomeDbRawForm *form);
 
 /* GnomeDbDataWidget interface */
@@ -54,15 +58,18 @@ static GtkActionGroup *gnome_db_raw_form_get_actions_group   (GnomeDbDataWidget
 static GdaDataModelIter *gnome_db_raw_form_widget_get_data_set   (GnomeDbDataWidget *iface);
 static GdaDataModel   *gnome_db_raw_form_widget_get_gda_model (GnomeDbDataWidget *iface);
 static void            gnome_db_raw_form_widget_set_gda_model (GnomeDbDataWidget *iface, GdaDataModel *model);
-
+static gboolean        gnome_db_raw_form_widget_set_write_mode (GnomeDbDataWidget *iface, GnomeDbDataWidgetWriteMode mode);
+static GnomeDbDataWidgetWriteMode gnome_db_raw_form_widget_get_write_mode (GnomeDbDataWidget *iface);
 
 struct _GnomeDbRawFormPriv
 {
-	GdaDataModel      *model;
-	GdaDataProxy      *proxy; /* proxy for @model */
-	GdaDataModelIter  *iter;  /* proxy's iter */
+	GdaDataModel               *model;
+	GdaDataProxy               *proxy; /* proxy for @model */
+	GdaDataModelIter           *iter;  /* proxy's iter */
 
-	GtkActionGroup    *actions_group;
+	GnomeDbDataWidgetWriteMode  write_mode;
+
+	GtkActionGroup             *actions_group;
 };
 
 #define PAGE_NO_DATA 0
@@ -120,9 +127,10 @@ gnome_db_raw_form_widget_init (GnomeDbDataWidgetIface *iface)
 	iface->get_data_set = gnome_db_raw_form_widget_get_data_set;
 	iface->get_gda_model = gnome_db_raw_form_widget_get_gda_model;
 	iface->set_gda_model = gnome_db_raw_form_widget_set_gda_model;
+	iface->set_write_mode = gnome_db_raw_form_widget_set_write_mode;
+	iface->get_write_mode = gnome_db_raw_form_widget_get_write_mode;
 }
 
-
 static void
 gnome_db_raw_form_class_init (GnomeDbRawFormClass * class)
 {
@@ -150,8 +158,8 @@ static void action_next_record_cb (GtkAction *action, GnomeDbRawForm *form);
 static void action_last_record_cb (GtkAction *action, GnomeDbRawForm *form);
 
 static GtkActionEntry ui_actions[] = {
-	{ "ActionNew", GTK_STOCK_NEW, "_New", NULL, "Create a new data entry", G_CALLBACK (action_new_cb)},
-	{ "ActionDelete", GTK_STOCK_DELETE, "_Delete", NULL, "Delete the selected entry", G_CALLBACK (action_delete_cb)},
+	{ "ActionNew", GTK_STOCK_ADD, "_New", NULL, "Create a new data entry", G_CALLBACK (action_new_cb)},
+	{ "ActionDelete", GTK_STOCK_REMOVE, "_Delete", NULL, "Delete the selected entry", G_CALLBACK (action_delete_cb)},
 	{ "ActionUndelete", GTK_STOCK_UNDELETE, "_Undelete", NULL, "Cancels the deletion of the current entry", 
 	  G_CALLBACK (action_undelete_cb)},	
 	{ "ActionCommit", GTK_STOCK_SAVE, "_Commit", NULL, "Commit the latest changes", G_CALLBACK (action_commit_cb)},
@@ -167,17 +175,82 @@ static GtkActionEntry ui_actions[] = {
 };
 
 static void
-gnome_db_raw_form_init (GnomeDbRawForm * wid)
+action_new_activated_cb (GtkAction *action, GnomeDbRawForm *wid)
 {
+	/* make the first entry grab the focus */
+	if (wid->priv->iter && GDA_PARAMETER_LIST (wid->priv->iter)->parameters)
+		gnome_db_basic_form_entry_grab_focus (GNOME_DB_BASIC_FORM (wid), 
+						      (GdaParameter *)
+						      GDA_PARAMETER_LIST (wid->priv->iter)->parameters->data);
+}
+
+static void
+form_activated_cb (GnomeDbRawForm *form, gpointer data)
+{
+	if (form->priv->write_mode == GNOME_DB_DATA_WIDGET_WRITE_ON_VALUE_ACTIVATED) {
+		gint row;
+
+		row = gda_data_model_iter_get_row (form->priv->iter);
+		if (row >= 0) {
+			/* write back the current row */
+			if (gda_data_proxy_row_has_changed (form->priv->proxy, row)) {
+				GError *error = NULL;
+				if (!gda_data_proxy_apply_row_changes (form->priv->proxy, row, &error)) {
+					gboolean discard;
+					discard = gnome_db_utility_display_error_with_keep_or_discard_choice ((GnomeDbDataWidget *) form, 
+												     error);
+					if (discard)
+						gda_data_proxy_cancel_row_changes (form->priv->proxy, row, -1);
+					g_error_free (error);
+				}
+			}
+		}
+	}
+}
+
+static void
+form_param_changed_cb (GnomeDbRawForm *form, gpointer data)
+{
+	if (form->priv->write_mode == GNOME_DB_DATA_WIDGET_WRITE_ON_VALUE_CHANGE) {
+		gint row;
+
+		row = gda_data_model_iter_get_row (form->priv->iter);
+		if (row >= 0) {
+			/* write back the current row */
+			if (gda_data_proxy_row_has_changed (form->priv->proxy, row)) {
+				GError *error = NULL;
+				if (!gda_data_proxy_apply_row_changes (form->priv->proxy, row, &error)) {
+					gnome_db_utility_display_error ((GnomeDbDataWidget *) form, TRUE, error);
+					if (error)
+						g_error_free (error);
+				}
+			}
+		}
+	}
+}
+
+static void
+gnome_db_raw_form_init (GnomeDbRawForm *wid)
+{
+	GtkAction *action;
 	wid->priv = g_new0 (GnomeDbRawFormPriv, 1);
 
 	wid->priv->model = NULL;
 	wid->priv->proxy = NULL;
 	wid->priv->iter = NULL;
+	wid->priv->write_mode = GNOME_DB_DATA_WIDGET_WRITE_ON_DEMAND;
+
+	g_signal_connect (G_OBJECT (wid), "activated",
+			  G_CALLBACK (form_activated_cb), NULL);
+	g_signal_connect (G_OBJECT (wid), "param_changed",
+			  G_CALLBACK (form_param_changed_cb), NULL);
 
 	/* action group */
         wid->priv->actions_group = gtk_action_group_new ("Actions");
         gtk_action_group_add_actions (wid->priv->actions_group, ui_actions, G_N_ELEMENTS (ui_actions), wid);
+	action = gtk_action_group_get_action (wid->priv->actions_group, "ActionNew");
+	g_signal_connect (G_OBJECT (action), "activate",
+			  G_CALLBACK (action_new_activated_cb), wid);
 }
 
 /**
@@ -212,6 +285,8 @@ gnome_db_raw_form_dispose (GObject *object)
 		if (form->priv->iter) {
 			g_signal_handlers_disconnect_by_func (form->priv->iter,
 							      G_CALLBACK (iter_row_changed_cb), form);
+			g_signal_handlers_disconnect_by_func (form->priv->iter,
+							      G_CALLBACK (iter_row_to_change_cb), form);
 			g_object_unref (form->priv->iter);
 			form->priv->iter = NULL;
 		}
@@ -222,6 +297,8 @@ gnome_db_raw_form_dispose (GObject *object)
 							      G_CALLBACK (proxy_row_inserted_or_removed_cb), form);
 			g_signal_handlers_disconnect_by_func (G_OBJECT (form->priv->proxy),
 							      G_CALLBACK (proxy_changed_cb), form);
+			g_signal_handlers_disconnect_by_func (G_OBJECT (form->priv->proxy),
+							      G_CALLBACK (proxy_reset_cb), form);
 			g_object_unref (form->priv->proxy);
 			form->priv->proxy = NULL;
 		}
@@ -241,9 +318,9 @@ gnome_db_raw_form_dispose (GObject *object)
 
 static void
 gnome_db_raw_form_set_property (GObject *object,
-			    guint param_id,
-			    const GValue *value,
-			    GParamSpec *pspec)
+				guint param_id,
+				const GValue *value,
+				GParamSpec *pspec)
 {
 	GnomeDbRawForm *form;
 	gpointer ptr;
@@ -259,6 +336,9 @@ gnome_db_raw_form_set_property (GObject *object,
 				/* remove old data model settings */
 				g_signal_handlers_disconnect_by_func (form->priv->iter,
 								      G_CALLBACK (iter_row_changed_cb), form);
+				g_signal_handlers_disconnect_by_func (form->priv->iter,
+								      G_CALLBACK (iter_row_to_change_cb), form);
+
 				g_object_unref (G_OBJECT (form->priv->iter));
 				form->priv->iter = NULL;
 				
@@ -267,6 +347,8 @@ gnome_db_raw_form_set_property (GObject *object,
 								      form);
 				g_signal_handlers_disconnect_by_func (G_OBJECT (form->priv->proxy),
 								      G_CALLBACK (proxy_changed_cb), form);
+				g_signal_handlers_disconnect_by_func (G_OBJECT (form->priv->proxy),
+								      G_CALLBACK (proxy_reset_cb), form);
 				g_object_unref (G_OBJECT (form->priv->proxy));
 				form->priv->proxy = NULL;
 				form->priv->model = NULL;
@@ -285,6 +367,8 @@ gnome_db_raw_form_set_property (GObject *object,
 				form->priv->iter = gda_data_model_create_iter ((GdaDataModel *) form->priv->proxy);
 				gda_data_model_iter_set_at_row (form->priv->iter, 0);
 
+				g_signal_connect (form->priv->iter, "row_to_change",
+						  G_CALLBACK (iter_row_to_change_cb), form);
 				g_signal_connect (form->priv->iter, "row_changed",
 						  G_CALLBACK (iter_row_changed_cb), form);
 
@@ -294,6 +378,8 @@ gnome_db_raw_form_set_property (GObject *object,
 						  G_CALLBACK (proxy_row_inserted_or_removed_cb), form);
 				g_signal_connect (G_OBJECT (form->priv->proxy), "changed",
 						  G_CALLBACK (proxy_changed_cb), form);
+				g_signal_connect (G_OBJECT (form->priv->proxy), "reset",
+						  G_CALLBACK (proxy_reset_cb), form);
 
 				/* we don't want chuncking */
 				g_object_set (object, "paramlist", form->priv->iter, NULL);
@@ -301,7 +387,9 @@ gnome_db_raw_form_set_property (GObject *object,
 				gnome_db_raw_form_initialize (form, NULL, NULL);
 			}
 
+			gnome_db_raw_form_widget_set_write_mode ((GnomeDbDataWidget *) form, form->priv->write_mode);
 			g_signal_emit_by_name (object, "proxy_changed", form->priv->proxy);
+			g_signal_emit_by_name (object, "iter_changed", form->priv->iter);
 			break;
 		default:
 			G_OBJECT_WARN_INVALID_PROPERTY_ID (object, param_id, pspec);
@@ -330,6 +418,29 @@ gnome_db_raw_form_get_property (GObject *object,
         }	
 }
 
+static gboolean
+iter_row_to_change_cb (GdaDataModelIter *iter, gint row, GnomeDbRawForm *form)
+{
+	gboolean allow_change = TRUE;
+	if (row >= 0) {
+		if (form->priv->write_mode >= GNOME_DB_DATA_WIDGET_WRITE_ON_ROW_CHANGE) {
+			/* write back the current row */
+			if (gda_data_proxy_row_has_changed (form->priv->proxy, row)) {
+				GError *error = NULL;
+				if (!gda_data_proxy_apply_row_changes (form->priv->proxy, row, &error)) {
+					allow_change = gnome_db_utility_display_error_with_keep_or_discard_choice ((GnomeDbDataWidget *) form, 
+													  error);
+					if (allow_change)
+						gda_data_proxy_cancel_row_changes (form->priv->proxy, row, -1);
+					g_error_free (error);
+				}
+			}
+		}
+	}
+	
+	return allow_change;
+}
+
 static void
 iter_row_changed_cb (GdaDataModelIter *iter, gint row, GnomeDbRawForm *form)
 {
@@ -343,11 +454,17 @@ iter_row_changed_cb (GdaDataModelIter *iter, gint row, GnomeDbRawForm *form)
 
 		params = ((GdaParameterList *) iter)->parameters;
 		while (params) {
+			gboolean explicit_hide = FALSE;
 			param = (GdaParameter *) params->data;
 			attributes = gda_data_proxy_get_value_attributes (form->priv->proxy, row, 
 							       gda_data_model_iter_get_column_for_param (iter, param));
 			gnome_db_basic_form_entry_set_editable ((GnomeDbBasicForm *) form, 
 								param, !(attributes & GDA_VALUE_ATTR_NO_MODIF));
+			if (GPOINTER_TO_INT (g_object_get_data (G_OBJECT (param), "_gnome_db_explicit_show")) == 1)
+				explicit_hide = TRUE;
+			if (!explicit_hide) 
+				gnome_db_basic_form_entry_show ((GnomeDbBasicForm *) form, 
+								param, !(attributes & GDA_VALUE_ATTR_UNUSED));
 			params = params->next;
 		}
 	}
@@ -361,6 +478,14 @@ proxy_changed_cb (GdaDataProxy *proxy, GnomeDbRawForm *form)
 				  gda_data_model_get_n_rows (GDA_DATA_MODEL (form->priv->proxy)) == 0 ? FALSE : TRUE);
 }
 
+static void
+proxy_reset_cb (GdaDataProxy *proxy, GnomeDbRawForm *form)
+{
+	g_object_ref (G_OBJECT (proxy));
+	g_object_set (G_OBJECT (form), "model", proxy, NULL);
+	g_object_unref (G_OBJECT (proxy));
+}
+
 static void
 proxy_row_inserted_or_removed_cb (GdaDataProxy *proxy, gint row, GnomeDbRawForm *form)
 {
@@ -408,7 +533,7 @@ gnome_db_raw_form_initialize (GnomeDbRawForm *form, GtkWidget *layout, GHashTabl
 	 * the form itself 
 	 */
 	if (!layout && gda_data_proxy_is_read_only (form->priv->proxy))
-		gnome_db_basic_form_show_entries_actions (GNOME_DB_BASIC_FORM (form), FALSE);
+		gnome_db_basic_form_show_entry_actions (GNOME_DB_BASIC_FORM (form), FALSE);
 
 	list = GDA_PARAMETER_LIST (form->priv->iter)->parameters;
 	while (list) {
@@ -417,9 +542,11 @@ gnome_db_raw_form_initialize (GnomeDbRawForm *form, GtkWidget *layout, GHashTabl
 		node = gda_parameter_list_find_node_for_param (GDA_PARAMETER_LIST (form->priv->iter), 
 							       GDA_PARAMETER (list->data));
 		g_assert (node);
-		if (node->hint & GDA_PARAMETER_LIST_PARAM_HIDE)
+		if (node->hint & GDA_PARAMETER_LIST_PARAM_HIDE) {
 			gnome_db_basic_form_entry_show (GNOME_DB_BASIC_FORM (form),
 							GDA_PARAMETER (list->data), FALSE);
+			g_object_set_data (G_OBJECT (list->data), "_gnome_db_explicit_show", GINT_TO_POINTER (1));
+		}
 		list = g_slist_next (list);
 	}
 
@@ -439,6 +566,10 @@ action_new_cb (GtkAction *action, GnomeDbRawForm *form)
 	GError *error = NULL;
 	GSList *list;
 
+	if (form->priv->write_mode >= GNOME_DB_DATA_WIDGET_WRITE_ON_ROW_CHANGE) 
+		if (! gda_data_model_iter_can_be_moved (form->priv->iter))
+			return;
+
 	/* append a row in the proxy */
 	newrow = gda_data_model_append_row (GDA_DATA_MODEL (form->priv->proxy), &error);
 	if (newrow == -1) {
@@ -462,12 +593,11 @@ action_new_cb (GtkAction *action, GnomeDbRawForm *form)
 									    GDA_PARAMETER (list->data));
 			gda_parameter_set_value (GDA_PARAMETER (list->data), value);
 		}
+		else
+			g_object_unref (param);
 		
 		list = g_slist_next (list);
 	}
-	
-	gnome_db_basic_form_set_entries_default (GNOME_DB_BASIC_FORM (form));
-	gnome_db_basic_form_set_entries_auto_default (GNOME_DB_BASIC_FORM (form), TRUE);
 }
 
 static void
@@ -478,6 +608,21 @@ action_delete_cb (GtkAction *action, GnomeDbRawForm *form)
 	row = gda_data_model_iter_get_row (form->priv->iter);
 	g_return_if_fail (row >= 0);
 	gda_data_proxy_delete (form->priv->proxy, row);
+
+	if (form->priv->write_mode >= GNOME_DB_DATA_WIDGET_WRITE_ON_ROW_CHANGE) {
+		/* force the proxy to apply the current row deletion */
+		gint newrow;
+
+		newrow = gda_data_model_iter_get_row (form->priv->iter);
+		if (row == newrow) {/* => row has been marked as delete but nit yet really deleted */
+			GError *error = NULL;
+			if (!gda_data_proxy_apply_row_changes (form->priv->proxy, row, &error)) {
+				gnome_db_utility_display_error ((GnomeDbDataWidget *) form, TRUE, error);
+				if (error)
+					g_error_free (error);
+			}
+		}
+	}
 }
 
 static void
@@ -493,7 +638,38 @@ action_undelete_cb (GtkAction *action, GnomeDbRawForm *form)
 static void
 action_commit_cb (GtkAction *action, GnomeDbRawForm *form)
 {
-	gda_data_proxy_apply_all_changes (form->priv->proxy, NULL);
+	gint row;
+	GError *error = NULL;
+	gboolean allok = TRUE;
+	gint mod1, mod2;
+
+	mod1 = gda_data_proxy_get_n_modified_rows (form->priv->proxy);
+	row = gda_data_model_iter_get_row (form->priv->iter);
+	if (form->priv->write_mode >= GNOME_DB_DATA_WIDGET_WRITE_ON_ROW_CHANGE) {
+		gint newrow;
+
+		allok = gda_data_proxy_apply_row_changes (form->priv->proxy, row, &error);
+		if (allok) {
+			newrow = gda_data_model_iter_get_row (form->priv->iter);
+			if (row != newrow) /* => current row has changed because the proxy had to emit a "row_removed" when
+					      actually succedded the commit 
+					      => we need to come back to that row
+					   */
+				gda_data_model_iter_set_at_row (form->priv->iter, row);
+		}
+	}
+	else
+		allok = gda_data_proxy_apply_all_changes (form->priv->proxy, &error);
+
+	mod2 = gda_data_proxy_get_n_modified_rows (form->priv->proxy);
+	if (!allok) {
+		if (mod1 != mod2)
+			/* the data model has changed while doing the writing */
+			gnome_db_utility_display_error ((GnomeDbDataWidget *) form, FALSE, error);
+		else
+			gnome_db_utility_display_error ((GnomeDbDataWidget *) form, TRUE, error);
+		g_error_free (error);
+	}
 }
 
 static void
@@ -595,6 +771,7 @@ gnome_db_raw_form_col_set_show (GnomeDbDataWidget *iface, gint column, gboolean
 	param = gda_data_model_iter_get_param_for_column (form->priv->iter, column);
 	g_return_if_fail (param);
 	gnome_db_basic_form_entry_show (GNOME_DB_BASIC_FORM (form), param, shown);
+	g_object_set_data (G_OBJECT (param), "_gnome_db_explicit_show", GINT_TO_POINTER (shown ? 2 : 1));
 }
 
 void
@@ -626,7 +803,7 @@ gnome_db_raw_form_show_column_actions (GnomeDbDataWidget *iface, gint column, gb
 	g_return_if_fail (form->priv);
 	
 	/* REM: don't take care of the @column argument */
-	gnome_db_basic_form_show_entries_actions (GNOME_DB_BASIC_FORM (form), show_actions);
+	gnome_db_basic_form_show_entry_actions (GNOME_DB_BASIC_FORM (form), show_actions);
 }
 
 static GtkActionGroup *
@@ -676,3 +853,28 @@ gnome_db_raw_form_widget_set_gda_model (GnomeDbDataWidget *iface, GdaDataModel *
 
 	g_object_set (form, "model", model, NULL);
 }
+
+static gboolean
+gnome_db_raw_form_widget_set_write_mode (GnomeDbDataWidget *iface, GnomeDbDataWidgetWriteMode mode)
+{
+	GnomeDbRawForm *form;
+	
+	g_return_val_if_fail (GNOME_DB_IS_RAW_FORM (iface), FALSE);
+	form = GNOME_DB_RAW_FORM (iface);
+	g_return_val_if_fail (form->priv, FALSE);
+
+	form->priv->write_mode = mode;
+	return TRUE;
+}
+
+static GnomeDbDataWidgetWriteMode
+gnome_db_raw_form_widget_get_write_mode (GnomeDbDataWidget *iface)
+{
+	GnomeDbRawForm *form;
+	
+	g_return_val_if_fail (GNOME_DB_IS_RAW_FORM (iface), GNOME_DB_DATA_WIDGET_WRITE_ON_DEMAND);
+	form = GNOME_DB_RAW_FORM (iface);
+	g_return_val_if_fail (form->priv, GNOME_DB_DATA_WIDGET_WRITE_ON_DEMAND);
+
+	return form->priv->write_mode;
+}
