@@ -1,6 +1,6 @@
 /* gnome-db-server-operation.c
  *
- * Copyright (C) 2006 Vivien Malerba
+ * Copyright (C) 2006 - 2007 Vivien Malerba
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License as
@@ -25,6 +25,7 @@
 #include "gnome-db-server-operation.h"
 #include "gnome-db-basic-form.h"
 #include "gnome-db-raw-grid.h"
+#include "gnome-db-raw-form.h"
 #include "gnome-db-data-store.h"
 #include "gnome-db-data-widget.h"
 #include "gnome-db-data-widget-info.h"
@@ -48,7 +49,8 @@ static void gnome_db_server_operation_fill (GnomeDbServerOperation *form);
 enum
 {
         PROP_0,
-	PROP_SERVER_OP_OBJ
+	PROP_SERVER_OP_OBJ,
+	PROP_OPT_HEADER
 };
 
 typedef struct _WidgetData {
@@ -65,6 +67,7 @@ struct _GnomeDbServerOperationPriv
 	GSList                 *widget_data; /* list of WidgetData structures */
 	GtkTooltips            *tooltips;
 	GladeXML               *glade;
+	gboolean                opt_header;
 };
 
 WidgetData *widget_data_new (WidgetData *parent, const gchar *path_name);
@@ -193,6 +196,11 @@ gnome_db_server_operation_class_init (GnomeDbServerOperationClass *class)
 							       NULL, GDA_TYPE_SERVER_OPERATION,
 							       G_PARAM_WRITABLE | G_PARAM_CONSTRUCT_ONLY |
 							       G_PARAM_READABLE));
+	g_object_class_install_property (object_class, PROP_OPT_HEADER,
+					 g_param_spec_boolean ("opt_header",
+							       _("Request section header to be hidden if there is only one section"),
+							       NULL, FALSE, G_PARAM_CONSTRUCT | G_PARAM_READABLE | 
+							       G_PARAM_WRITABLE));
 }
 
 static void
@@ -205,6 +213,7 @@ gnome_db_server_operation_init (GnomeDbServerOperation * wid)
 	g_object_ref (G_OBJECT (wid->priv->tooltips));
 	gtk_object_sink (GTK_OBJECT (wid->priv->tooltips));
 	wid->priv->glade = NULL;
+	wid->priv->opt_header = FALSE;
 }
 
 
@@ -238,7 +247,7 @@ gnome_db_server_operation_dispose (GObject *object)
 	GnomeDbServerOperation *form;
 
 	g_return_if_fail (object != NULL);
-	g_return_if_fail (IS_GNOME_DB_SERVER_OPERATION (object));
+	g_return_if_fail (GNOME_DB_IS_SERVER_OPERATION (object));
 	form = GNOME_DB_SERVER_OPERATION (object);
 
 	if (form->priv) {
@@ -301,6 +310,9 @@ gnome_db_server_operation_set_property (GObject *object,
 						  G_CALLBACK (sequence_item_remove_cb), form);
 			}
 			break;
+		case PROP_OPT_HEADER:
+			form->priv->opt_header = g_value_get_boolean (value);
+			break;
 		default:
 			G_OBJECT_WARN_INVALID_PROPERTY_ID (object, param_id, pspec);
 			break;
@@ -322,6 +334,9 @@ gnome_db_server_operation_get_property (GObject *object,
 		case PROP_SERVER_OP_OBJ:
 			g_value_set_object (value, form->priv->op);
 			break;
+		case PROP_OPT_HEADER:
+			g_value_set_boolean (value, form->priv->opt_header);
+			break;
 		default:
 			G_OBJECT_WARN_INVALID_PROPERTY_ID (object, param_id, pspec);
 			break;
@@ -375,6 +390,8 @@ sequence_table_attach_widget (GnomeDbServerOperation *form, GtkWidget *table, Gt
 		gtk_widget_set_sensitive (wid, FALSE);
 }
 
+static GtkWidget *create_table_fields_array_create_widget (GnomeDbServerOperation *form, const gchar *path, 
+							   gchar **section_str, GSList **label_widgets);
 static GtkWidget *
 fill_create_widget (GnomeDbServerOperation *form, const gchar *path, gchar **section_str, GSList **label_widgets)
 {
@@ -386,14 +403,22 @@ fill_create_widget (GnomeDbServerOperation *form, const gchar *path, gchar **sec
 
 	if (label_widgets)
 		*label_widgets = NULL;
+	if (section_str)
+		*section_str = NULL;
 
+	/* very custom widget rendering goes here */
+	if ((gda_server_operation_get_op_type (form->priv->op) == GDA_SERVER_OPERATION_CREATE_TABLE) &&
+	    !strcmp (path, "/FIELDS_A")) 
+		return create_table_fields_array_create_widget (form, path, section_str, label_widgets);
+
+	/* generic widget rendering */
 	switch (info_node->type) {
 	case GDA_SERVER_OPERATION_NODE_PARAMLIST: {
 		GdaParameterList *plist;
 
 		plist = info_node->plist;
 		plwid = gnome_db_basic_form_new (plist);
-		gnome_db_basic_form_show_entries_actions (GNOME_DB_BASIC_FORM (plwid),
+		gnome_db_basic_form_show_entry_actions (GNOME_DB_BASIC_FORM (plwid),
 							  FALSE);
 	       
 		if (section_str) {
@@ -423,7 +448,6 @@ fill_create_widget (GnomeDbServerOperation *form, const gchar *path, gchar **sec
 	}
 	case GDA_SERVER_OPERATION_NODE_DATA_MODEL: {
 		GdaDataModel *model;
-		GtkTreeModel *treemodel;
 		GdaDataProxy *proxy;
 		GtkWidget *winfo;
 		GtkWidget *box, *grid;
@@ -439,15 +463,15 @@ fill_create_widget (GnomeDbServerOperation *form, const gchar *path, gchar **sec
 		gtk_scrolled_window_add_with_viewport (GTK_SCROLLED_WINDOW (plwid), grid);
 		gtk_viewport_set_shadow_type (GTK_VIEWPORT (gtk_bin_get_child (GTK_BIN (plwid))), 
 					      GTK_SHADOW_NONE);
+		gnome_db_data_widget_set_write_mode (GNOME_DB_DATA_WIDGET (grid),
+						     GNOME_DB_DATA_WIDGET_WRITE_ON_ROW_CHANGE);
 		gtk_widget_show (grid);
 
-		treemodel = gtk_tree_view_get_model (GTK_TREE_VIEW (grid));
-		proxy = gnome_db_data_store_get_proxy (GNOME_DB_DATA_STORE (treemodel));
-		g_object_set (G_OBJECT (proxy), "autocommit", TRUE, NULL);
+		proxy = gnome_db_data_widget_get_proxy (GNOME_DB_DATA_WIDGET (grid));
 		g_object_set (G_OBJECT (grid), "info-cell-visible", FALSE, NULL);
 
 		winfo = gnome_db_data_widget_info_new (GNOME_DB_DATA_WIDGET (grid), 
-						       GNOME_DB_DATA_WIDGET_INFO_ROW_MODIF_BUTTONS);
+						       GNOME_DB_DATA_WIDGET_INFO_ROW_MODIFY_BUTTONS);
 
 		box = gtk_vbox_new (FALSE, 0);
 		gtk_box_pack_start (GTK_BOX (box), plwid, TRUE, TRUE, 0);
@@ -503,7 +527,7 @@ fill_create_widget (GnomeDbServerOperation *form, const gchar *path, gchar **sec
 		plist = gda_parameter_list_new (list);
 		g_slist_free (list);
 		plwid = gnome_db_basic_form_new (plist);
-		gnome_db_basic_form_show_entries_actions (GNOME_DB_BASIC_FORM (plwid),
+		gnome_db_basic_form_show_entry_actions (GNOME_DB_BASIC_FORM (plwid),
 							  FALSE);
 		/* we don't need plist anymore */
 		g_object_unref (plist);
@@ -730,7 +754,7 @@ gnome_db_server_operation_fill (GnomeDbServerOperation *form)
 			GdaServerOperationNodeStatus status;			
 			GtkWidget *label = NULL, *hbox = NULL;
 
-			if (section_str) {
+			if (! (form->priv->opt_header && (g_strv_length (topnodes) == 1)) && section_str) {
 				GtkWidget *lab;
 				label = gtk_label_new ("");
 				gtk_widget_show (label);
@@ -1093,3 +1117,121 @@ gnome_db_server_operation_new_in_dialog (GdaServerOperation *op, GtkWindow *pare
 
 	return dlg;
 }
+
+
+/*
+ * CREATE_TABLE "/FIELDS_A" Custom widgets rendering
+ */
+static void create_table_grid_fields_iter_row_changed_cb (GdaDataModelIter *grid_iter, gint row, 
+							  GdaDataModelIter *form_iter);
+static GtkWidget *
+create_table_fields_array_create_widget (GnomeDbServerOperation *form, const gchar *path, 
+					 gchar **section_str, GSList **label_widgets)
+{
+	GdaServerOperationNode *info_node;
+	GtkWidget *hlayout, *sw, *box, *label;
+	GtkWidget *grid_fields, *form_props, *winfo;
+	GdaDataProxy *proxy;
+	gint name_col, col, nbcols;
+	GdaDataModelIter *grid_iter, *form_iter;
+		
+	info_node = gda_server_operation_get_node_info (form->priv->op, path);
+	g_assert (info_node->type == GDA_SERVER_OPERATION_NODE_DATA_MODEL);
+
+	hlayout = gtk_hpaned_new ();
+	gtk_widget_set_usize (hlayout, 800, 600);
+
+	/* form for field properties */
+	box = gtk_vbox_new (FALSE, 0);
+	gtk_paned_pack2 (GTK_PANED (hlayout), box, TRUE, TRUE);
+
+	label = gtk_label_new (_("<b>Field properties:</b>"));
+	gtk_label_set_use_markup (GTK_LABEL (label), TRUE);
+	gtk_misc_set_alignment (GTK_MISC (label), 0., -1);
+	gtk_box_pack_start (GTK_BOX (box), label, FALSE, FALSE, 0);
+
+	form_props = gnome_db_raw_form_new (GDA_DATA_MODEL (info_node->model));
+	proxy = gnome_db_data_widget_get_proxy (GNOME_DB_DATA_WIDGET (form_props));
+	gnome_db_data_widget_set_write_mode (GNOME_DB_DATA_WIDGET (form_props),
+					     GNOME_DB_DATA_WIDGET_WRITE_ON_VALUE_CHANGE);
+	gtk_box_pack_start (GTK_BOX (box), form_props, TRUE, TRUE, 0);
+
+	gtk_widget_show_all (box);
+
+	/* grid for field names */
+	box = gtk_vbox_new (FALSE, 0);
+	gtk_paned_pack1 (GTK_PANED (hlayout), box, TRUE, TRUE);
+
+	label = gtk_label_new (_("<b>Fields:</b>"));
+	gtk_label_set_use_markup (GTK_LABEL (label), TRUE);
+	gtk_misc_set_alignment (GTK_MISC (label), 0., -1);
+	gtk_box_pack_start (GTK_BOX (box), label, FALSE, FALSE, 0);
+
+	sw = gtk_scrolled_window_new (NULL, NULL);
+	gtk_scrolled_window_set_policy (GTK_SCROLLED_WINDOW (sw), 
+					GTK_POLICY_AUTOMATIC, GTK_POLICY_AUTOMATIC);
+	gtk_scrolled_window_set_shadow_type (GTK_SCROLLED_WINDOW (sw), GTK_SHADOW_NONE);
+
+	grid_fields = gnome_db_raw_grid_new (GDA_DATA_MODEL(proxy));
+	gtk_tree_view_set_headers_visible (GTK_TREE_VIEW (grid_fields), FALSE);
+	gtk_widget_set_usize (grid_fields, 300, 200);
+	g_object_set (G_OBJECT (grid_fields), "info-cell-visible", FALSE, NULL);	
+
+	/*name_col = gda_data_model_get_column_index_by_name (GDA_DATA_MODEL (proxy), "rr");*/
+	name_col = 0;
+	nbcols = gda_data_proxy_get_proxied_model_n_cols (proxy);
+	g_assert (name_col < nbcols);
+	for (col = 0; col < name_col; col++)
+		gnome_db_data_widget_column_hide (GNOME_DB_DATA_WIDGET (grid_fields), col);
+	for (col = name_col + 1; col < nbcols; col++)
+		gnome_db_data_widget_column_hide (GNOME_DB_DATA_WIDGET (grid_fields), col);
+
+	gtk_scrolled_window_add_with_viewport (GTK_SCROLLED_WINDOW (sw), grid_fields);
+	gtk_viewport_set_shadow_type (GTK_VIEWPORT (gtk_bin_get_child (GTK_BIN (sw))), 
+				      GTK_SHADOW_NONE);
+	gtk_box_pack_start (GTK_BOX (box), sw, TRUE, TRUE, 0);
+
+	/* buttons to add/remove fields */
+	winfo = gnome_db_data_widget_info_new (GNOME_DB_DATA_WIDGET (form_props), 
+					       GNOME_DB_DATA_WIDGET_INFO_ROW_MODIFY_BUTTONS);
+
+	gtk_box_pack_start (GTK_BOX (box), winfo, FALSE, FALSE, 0);
+
+	gtk_widget_show_all (box);
+
+	/* keep the selections in sync */
+	grid_iter = gnome_db_data_widget_get_current_data (GNOME_DB_DATA_WIDGET (grid_fields));
+	form_iter = gnome_db_data_widget_get_current_data (GNOME_DB_DATA_WIDGET (form_props));
+	g_signal_connect (grid_iter, "row_changed",
+			  G_CALLBACK (create_table_grid_fields_iter_row_changed_cb), form_iter);
+	g_signal_connect (form_iter, "row_changed",
+			  G_CALLBACK (create_table_grid_fields_iter_row_changed_cb), grid_iter);
+
+	g_object_set_data (G_OBJECT (hlayout), "expand", GINT_TO_POINTER (TRUE));
+
+	{
+		GtkActionGroup *group;
+		GtkAction *action;
+		group = gnome_db_data_widget_get_actions_group (GNOME_DB_DATA_WIDGET (form_props));
+		action = gtk_action_group_get_action (group, "ActionNew");
+		g_object_set (G_OBJECT (action), "tooltip", _("Add a new field"), NULL);
+		action = gtk_action_group_get_action (group, "ActionDelete");
+		g_object_set (G_OBJECT (action), "tooltip", _("Remove selected field"), NULL);
+		action = gtk_action_group_get_action (group, "ActionCommit");
+		gtk_action_set_visible (action, FALSE);
+		action = gtk_action_group_get_action (group, "ActionReset");
+		gtk_action_set_visible (action, FALSE);
+	}
+
+	return hlayout;
+}
+
+static void
+create_table_grid_fields_iter_row_changed_cb (GdaDataModelIter *iter1, gint row, GdaDataModelIter *iter2)
+{
+	g_signal_handlers_block_by_func (G_OBJECT (iter2),
+					 G_CALLBACK (create_table_grid_fields_iter_row_changed_cb), iter1);
+	gda_data_model_iter_set_at_row (iter2, row);
+	g_signal_handlers_unblock_by_func (G_OBJECT (iter2),
+					   G_CALLBACK (create_table_grid_fields_iter_row_changed_cb), iter1);
+}
