@@ -425,7 +425,7 @@ gnome_db_option_menu_get_selection (GtkOptionMenu *option_menu)
 	g_return_val_if_fail (GTK_IS_OPTION_MENU (option_menu), NULL);
 
 	menu = gtk_option_menu_get_menu(option_menu);
-	menu_item = gtk_menu_get_active(menu);
+	menu_item = gtk_menu_get_active(GTK_MENU(menu));
 
 	if (GTK_IS_MENU_ITEM (menu_item)) {
 		return (const gchar *) g_object_get_data (G_OBJECT (menu_item),
@@ -637,7 +637,7 @@ gnome_db_select_file_dialog (GtkWidget *parent, const gchar *title)
 
 #if GTK_CHECK_VERSION(2,4,0)
 	/* create dialog */
-	filesel = gtk_file_chooser_dialog_new (title, parent, GTK_FILE_CHOOSER_ACTION_SAVE,
+	filesel = gtk_file_chooser_dialog_new (title, GTK_WINDOW(parent), GTK_FILE_CHOOSER_ACTION_SAVE,
 					       GTK_STOCK_CANCEL, GTK_RESPONSE_CANCEL,
 					       GTK_STOCK_OK, GTK_RESPONSE_OK,
 					       NULL);
@@ -686,74 +686,20 @@ gnome_db_new_alert (GtkWindow *parent,
 		    const gchar *primary_text,
 		    const gchar *secondary_text)
 {
-	const gchar *stock_id = NULL;
-	gchar *str;
 	GtkWidget *dialog;
-	GtkWidget *image;
-	GtkWidget *label;
-	GtkWidget *hbox;
-	GtkWidget *vbox;
+	gchar *str;
 
-	g_return_val_if_fail (primary_text != NULL, NULL);
-
-	dialog = gtk_dialog_new_with_buttons ("",
-					     parent,
-					     GTK_DIALOG_DESTROY_WITH_PARENT |
-					     GTK_DIALOG_NO_SEPARATOR |
-					     GTK_DIALOG_MODAL,
-					     NULL);
-					     
-	gtk_window_set_resizable (GTK_WINDOW (dialog), FALSE);
-	gtk_container_set_border_width (GTK_CONTAINER (dialog), 6);
-	gtk_box_set_spacing (GTK_BOX (GTK_DIALOG (dialog)->vbox), 12);
-
-	hbox = gtk_hbox_new (FALSE, 12);
-	gtk_container_set_border_width (GTK_CONTAINER (hbox), 6);
-	gtk_box_pack_start (GTK_BOX (GTK_DIALOG (dialog)->vbox), hbox,
-			    TRUE, TRUE, 0);
-
-	switch (type) {
-	case GTK_MESSAGE_INFO:
-		stock_id = GTK_STOCK_DIALOG_INFO;
-		break;
-	case GTK_MESSAGE_WARNING:
-		stock_id = GTK_STOCK_DIALOG_WARNING;
-		break;
-	case GTK_MESSAGE_QUESTION:
-		stock_id = GTK_STOCK_DIALOG_QUESTION;
-		break;
-	case GTK_MESSAGE_ERROR:
-		stock_id = GTK_STOCK_DIALOG_ERROR;
-		break;
-	}
-	g_return_val_if_fail (stock_id != NULL, NULL);
-
-	image = gtk_image_new_from_stock (stock_id,
-					  GTK_ICON_SIZE_DIALOG);
-	gtk_misc_set_alignment (GTK_MISC (image), 0.5, 0.0);
-	gtk_box_pack_start (GTK_BOX (hbox), image, TRUE, TRUE, 0);
-
-	vbox = gtk_vbox_new (FALSE, 6);
-	gtk_box_pack_start (GTK_BOX (hbox), vbox, TRUE, TRUE, 0);
-
-	label = gtk_label_new (NULL);
-	gtk_misc_set_alignment (GTK_MISC (label), 0.0, 0.5);
-	gtk_label_set_line_wrap (GTK_LABEL (label), TRUE);
-	str = g_strconcat ("<span weight=\"bold\" size=\"larger\">",
+	str = g_strconcat ("<span weight=\"bold\">",
 			   primary_text,
-			   "</span>",
+			   "</span>\n",
+			   secondary_text,
 			   NULL);
-	gtk_label_set_markup (GTK_LABEL (label), str);
-	g_free (str);
-	gtk_box_pack_start (GTK_BOX (vbox), label, TRUE, TRUE, 0);
-
-	if (secondary_text != NULL) {
-		label = gtk_label_new (secondary_text);
-		gtk_misc_set_alignment (GTK_MISC (label), 0.0, 0.5);
-		gtk_label_set_line_wrap (GTK_LABEL (label), TRUE);
-		gtk_box_pack_start (GTK_BOX (vbox), label, TRUE, TRUE, 0);
-	}
 
+	dialog = gtk_message_dialog_new_with_markup (parent, 
+						     GTK_DIALOG_DESTROY_WITH_PARENT |
+						     GTK_DIALOG_MODAL, type,
+						     GTK_BUTTONS_CLOSE, str);
+	
 	return dialog;
 }
 
@@ -764,7 +710,7 @@ gnome_db_new_alert (GtkWindow *parent,
  *
  */
 void
-gnome_db_show_error (const gchar *format, ...)
+gnome_db_show_error (GtkWindow *parent, const gchar *format, ...)
 {
 	va_list args;
         gchar sz[2048];
@@ -776,36 +722,7 @@ gnome_db_show_error (const gchar *format, ...)
         va_end (args);
 
 	/* create the error message dialog */
-	dialog = gnome_db_new_alert (NULL, GTK_MESSAGE_ERROR, sz, NULL);
-	gtk_dialog_add_action_widget (GTK_DIALOG (dialog),
-				      gtk_button_new_from_stock (GTK_STOCK_OK),
-				      GTK_RESPONSE_OK);
-	gtk_widget_show_all (dialog);
-	gtk_dialog_run (GTK_DIALOG (dialog));
-	gtk_widget_destroy (dialog);
-}
-
-/**
- * gnome_db_show_message
- * @format: Format string.
- * @...:
- *
- * Displays an information message to the user.
- */
-void
-gnome_db_show_message (const gchar *format, ...)
-{
-	va_list args;
-        gchar sz[2048];
-	GtkWidget *dialog;
-
-	/* build the message string */
-        va_start (args, format);
-        vsnprintf (sz, sizeof sz, format, args);
-        va_end (args);
-
-	/* create the info message dialog */
-	dialog = gnome_db_new_alert (NULL, GTK_MESSAGE_INFO, sz, NULL);
+	dialog = gnome_db_new_alert (parent, GTK_MESSAGE_ERROR, _("Error:"), sz);
 	gtk_dialog_add_action_widget (GTK_DIALOG (dialog),
 				      gtk_button_new_from_stock (GTK_STOCK_OK),
 				      GTK_RESPONSE_OK);
